@@ -1,4 +1,4 @@
-/* $OpenBSD: x509_alt.c,v 1.14 2022/11/14 17:48:50 beck Exp $ */
+/* $OpenBSD: x509_alt.c,v 1.16 2023/08/30 00:49:32 tb Exp $ */
 /* Written by Dr Stephen N Henson (steve@openssl.org) for the OpenSSL
  * project.
  */
@@ -152,7 +152,7 @@ i2v_GENERAL_NAMES(X509V3_EXT_METHOD *method, GENERAL_NAMES *gens,
 
 	return NULL;
 }
-LCRYPTO_ALIAS(i2v_GENERAL_NAMES)
+LCRYPTO_ALIAS(i2v_GENERAL_NAMES);
 
 STACK_OF(CONF_VALUE) *
 i2v_GENERAL_NAME(X509V3_EXT_METHOD *method, GENERAL_NAME *gen,
@@ -245,7 +245,7 @@ i2v_GENERAL_NAME(X509V3_EXT_METHOD *method, GENERAL_NAME *gen,
 
 	return NULL;
 }
-LCRYPTO_ALIAS(i2v_GENERAL_NAME)
+LCRYPTO_ALIAS(i2v_GENERAL_NAME);
 
 int
 GENERAL_NAME_print(BIO *out, GENERAL_NAME *gen)
@@ -312,7 +312,7 @@ GENERAL_NAME_print(BIO *out, GENERAL_NAME *gen)
 	}
 	return 1;
 }
-LCRYPTO_ALIAS(GENERAL_NAME_print)
+LCRYPTO_ALIAS(GENERAL_NAME_print);
 
 static GENERAL_NAMES *
 v2i_issuer_alt(X509V3_EXT_METHOD *method, X509V3_CTX *ctx,
@@ -354,10 +354,11 @@ err:
 static int
 copy_issuer(X509V3_CTX *ctx, GENERAL_NAMES *gens)
 {
-	GENERAL_NAMES *ialt;
-	GENERAL_NAME *gen;
+	GENERAL_NAMES *ialt = NULL;
+	GENERAL_NAME *gen = NULL;
 	X509_EXTENSION *ext;
 	int i;
+	int ret = 0;
 
 	if (ctx && (ctx->flags == CTX_TEST))
 		return 1;
@@ -375,19 +376,24 @@ copy_issuer(X509V3_CTX *ctx, GENERAL_NAMES *gens)
 	}
 
 	for (i = 0; i < sk_GENERAL_NAME_num(ialt); i++) {
-		gen = sk_GENERAL_NAME_value(ialt, i);
+		GENERAL_NAME *val = sk_GENERAL_NAME_value(ialt, i);
+
+		if ((gen = GENERAL_NAME_dup(val)) == NULL)
+			goto err;
 		if (!sk_GENERAL_NAME_push(gens, gen)) {
 			X509V3error(ERR_R_MALLOC_FAILURE);
 			goto err;
 		}
+		gen = NULL;
 	}
-	sk_GENERAL_NAME_free(ialt);
 
-	return 1;
+	ret = 1;
 
-err:
-	return 0;
+ err:
+	sk_GENERAL_NAME_pop_free(ialt, GENERAL_NAME_free);
+	GENERAL_NAME_free(gen);
 
+	return ret;
 }
 
 static GENERAL_NAMES *
@@ -515,7 +521,7 @@ err:
 	sk_GENERAL_NAME_pop_free(gens, GENERAL_NAME_free);
 	return NULL;
 }
-LCRYPTO_ALIAS(v2i_GENERAL_NAMES)
+LCRYPTO_ALIAS(v2i_GENERAL_NAMES);
 
 GENERAL_NAME *
 v2i_GENERAL_NAME(const X509V3_EXT_METHOD *method, X509V3_CTX *ctx,
@@ -523,7 +529,7 @@ v2i_GENERAL_NAME(const X509V3_EXT_METHOD *method, X509V3_CTX *ctx,
 {
 	return v2i_GENERAL_NAME_ex(NULL, method, ctx, cnf, 0);
 }
-LCRYPTO_ALIAS(v2i_GENERAL_NAME)
+LCRYPTO_ALIAS(v2i_GENERAL_NAME);
 
 GENERAL_NAME *
 a2i_GENERAL_NAME(GENERAL_NAME *out, const X509V3_EXT_METHOD *method,
@@ -614,7 +620,7 @@ err:
 		GENERAL_NAME_free(gen);
 	return NULL;
 }
-LCRYPTO_ALIAS(a2i_GENERAL_NAME)
+LCRYPTO_ALIAS(a2i_GENERAL_NAME);
 
 GENERAL_NAME *
 v2i_GENERAL_NAME_ex(GENERAL_NAME *out, const X509V3_EXT_METHOD *method,
@@ -718,7 +724,7 @@ v2i_GENERAL_NAME_ex(GENERAL_NAME *out, const X509V3_EXT_METHOD *method,
 		GENERAL_NAME_free(ret);
 	return NULL;
 }
-LCRYPTO_ALIAS(v2i_GENERAL_NAME_ex)
+LCRYPTO_ALIAS(v2i_GENERAL_NAME_ex);
 
 static int
 do_othername(GENERAL_NAME *gen, const char *value, X509V3_CTX *ctx)
