@@ -1,23 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Tristan Matthews <tristan.matthews@savoirfairelinux.com>
- *  Author: Guillaume Roguez <Guillaume.Roguez@savoirfairelinux.com>
- *  Author: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "client/videomanager.h"
@@ -25,10 +20,10 @@
 #include "video_sender.h"
 #include "video_receive_thread.h"
 #include "video_mixer.h"
-#include "connectivity/ice_socket.h"
 #include "socket_pair.h"
 #include "sip/sipvoiplink.h" // for enqueueKeyframeRequest
 #include "manager.h"
+#include "media_const.h"
 #ifdef ENABLE_PLUGIN
 #include "plugin/streamdata.h"
 #include "plugin/jamipluginmanager.h"
@@ -41,6 +36,10 @@
 
 #include "account_const.h"
 
+#include <dhtnet/ice_socket.h>
+#include <asio/post.hpp>
+#include <asio/io_context.hpp>
+
 #include <sstream>
 #include <map>
 #include <string>
@@ -67,18 +66,18 @@ VideoRtpSession::VideoRtpSession(const string& callId,
     , localVideoParams_(localVideoParams)
     , videoBitrateInfo_ {}
     , rtcpCheckerThread_([] { return true; }, [this] { processRtcpChecker(); }, [] {})
+    , cc(std::make_unique<CongestionControl>())
 {
     recorder_ = rec;
     setupVideoBitrateInfo(); // reset bitrate
-    cc = std::make_unique<CongestionControl>();
-    JAMI_DBG("[%p] Video RTP session created for call %s", this, callId_.c_str());
+    JAMI_LOG("[{:p}] Video RTP session created for call {} (recorder {:p})", fmt::ptr(this), callId_, fmt::ptr(recorder_));
 }
 
 VideoRtpSession::~VideoRtpSession()
 {
     deinitRecorder();
     stop();
-    JAMI_DBG("[%p] Video RTP session destroyed", this);
+    JAMI_LOG("[{:p}] Video RTP session destroyed", fmt::ptr(this));
 }
 
 const VideoBitrateInfo&
@@ -93,6 +92,13 @@ void
 VideoRtpSession::updateMedia(const MediaDescription& send, const MediaDescription& receive)
 {
     BaseType::updateMedia(send, receive);
+    // adjust send->codec bitrate info for higher video resolutions
+    auto codecVideo = std::static_pointer_cast<jami::SystemVideoCodecInfo>(send_.codec);
+    if (codecVideo) {
+        auto const pixels = localVideoParams_.height * localVideoParams_.width;
+        codecVideo->bitrate = std::max((unsigned int)(pixels * 0.001), SystemCodecInfo::DEFAULT_VIDEO_BITRATE);
+        codecVideo->maxBitrate = std::max((unsigned int)(pixels * 0.0015), SystemCodecInfo::DEFAULT_MAX_BITRATE);
+    }
     setupVideoBitrateInfo();
 }
 
@@ -105,7 +111,7 @@ VideoRtpSession::setRequestKeyFrameCallback(std::function<void(void)> cb)
 void
 VideoRtpSession::startSender()
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
     JAMI_DBG("[%p] Start video RTP sender: input [%s] - muted [%s]",
              this,
@@ -128,14 +134,16 @@ VideoRtpSession::startSender()
         }
 
         if (not conference_) {
-            auto input = getVideoInput(input_);
-            videoLocal_ = input;
-            if (input) {
+            videoLocal_ = getVideoInput(input_);
+            if (videoLocal_) {
                 videoLocal_->setRecorderCallback(
-                    [this](const MediaStream& ms) {
-                        attachLocalRecorder(ms);
+                    [w=weak_from_this()](const MediaStream& ms) {
+                        asio::post(*Manager::instance().ioContext(), [w=std::move(w), ms]() {
+                            if (auto shared = w.lock())
+                                shared->attachLocalRecorder(ms);
+                        });
                     });
-                auto newParams = input->getParams();
+                auto newParams = videoLocal_->getParams();
                 try {
                     if (newParams.valid()
                         && newParams.wait_for(NEWPARAMS_TIMEOUT) == std::future_status::ready) {
@@ -149,22 +157,19 @@ VideoRtpSession::startSender()
                     return;
                 }
             } else {
-                JAMI_WARN("Can't lock video input");
+                JAMI_WARN("Unable to lock video input");
                 return;
             }
 
-#ifdef __ANDROID__
-            if (auto input1 = std::static_pointer_cast<VideoInput>(videoLocal_)) {
-                input1->setupSink();
-                input1->setFrameSize(localVideoParams_.width, localVideoParams_.height);
-            }
+#if (defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS))
+            videoLocal_->setupSink(localVideoParams_.width, localVideoParams_.height);
 #endif
         }
 
         // be sure to not send any packets before saving last RTP seq value
         socketPair_->stopSendOp();
 
-        auto codecVideo = std::static_pointer_cast<jami::AccountVideoCodecInfo>(send_.codec);
+        auto codecVideo = std::static_pointer_cast<jami::SystemVideoCodecInfo>(send_.codec);
         auto autoQuality = codecVideo->isAutoQualityEnabled;
 
         send_.linkableHW = conference_ == nullptr;
@@ -173,7 +178,7 @@ VideoRtpSession::startSender()
         // Current implementation does not handle resolution change
         // (needed by window sharing feature) with HW codecs, so HW
         // codecs will be disabled for now.
-        bool allowHwAccel = (localVideoParams_.format != "x11grab" && localVideoParams_.format != "dxgigrab");
+        bool allowHwAccel = (localVideoParams_.format != "x11grab" && localVideoParams_.format != "dxgigrab" && localVideoParams_.format != "lavfi");
 
         if (socketPair_)
             initSeqVal_ = socketPair_->lastSeqValOut();
@@ -186,8 +191,8 @@ VideoRtpSession::startSender()
                       ? MediaStream("video sender",
                                     AV_PIX_FMT_YUV420P,
                                     1 / static_cast<rational<int>>(localVideoParams_.framerate),
-                                    localVideoParams_.width,
-                                    localVideoParams_.height,
+                                    localVideoParams_.width == 0 ? 1080u : localVideoParams_.width,
+                                    localVideoParams_.height == 0 ? 720u : localVideoParams_.height,
                                     send_.bitrate,
                                     static_cast<rational<int>>(localVideoParams_.framerate))
                       : videoMixer_->getStream("Video Sender");
@@ -209,13 +214,16 @@ VideoRtpSession::startSender()
             rtcpCheckerThread_.start();
         else if (not autoQuality and rtcpCheckerThread_.isRunning())
             rtcpCheckerThread_.join();
+        // Block reads to received feedback packets
+        if(socketPair_)
+            socketPair_->setReadBlockingMode(true);
     }
 }
 
 void
 VideoRtpSession::restartSender()
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
     // ensure that start has been called before restart
     if (not socketPair_)
@@ -230,7 +238,7 @@ VideoRtpSession::restartSender()
 }
 
 void
-VideoRtpSession::stopSender()
+VideoRtpSession::stopSender(bool forceStopSocket)
 {
     // Concurrency protection must be done by caller.
 
@@ -247,8 +255,13 @@ VideoRtpSession::stopSender()
         sender_.reset();
     }
 
-    if (socketPair_)
-        socketPair_->stopSendOp();
+    if (socketPair_) {
+        bool const isReceivingVideo = receive_.enabled && !receive_.onHold;
+        if(forceStopSocket || !isReceivingVideo) {
+            socketPair_->stopSendOp();
+            socketPair_->setReadBlockingMode(false);
+        }
+    }
 }
 
 void
@@ -264,6 +277,10 @@ VideoRtpSession::startReceiver()
         receiveThread_.reset(
             new VideoReceiveThread(callId_, !conference_, receive_.receiving_sdp, mtu_));
 
+        // ensure that start has been called
+        if (not socketPair_)
+            return;
+
         // XXX keyframe requests can timeout if unanswered
         receiveThread_->addIOContext(*socketPair_);
         receiveThread_->setSuccessfulSetupCb(onSuccessfulSetup_);
@@ -279,9 +296,12 @@ VideoRtpSession::startReceiver()
             if (activeStream)
                 videoMixer_->setActiveStream(streamId_);
         }
-        receiveThread_->setRecorderCallback(
-            [this](const MediaStream& ms) { attachRemoteRecorder(ms); });
-
+        receiveThread_->setRecorderCallback([w=weak_from_this()](const MediaStream& ms) {
+            asio::post(*Manager::instance().ioContext(), [w=std::move(w), ms]() {
+                if (auto shared = w.lock())
+                    shared->attachRemoteRecorder(ms);
+            });
+        });
     } else {
         JAMI_DBG("[%p] Video receiver disabled", this);
         if (receiveThread_ and videoMixer_ and conference_) {
@@ -300,7 +320,7 @@ VideoRtpSession::startReceiver()
 }
 
 void
-VideoRtpSession::stopReceiver()
+VideoRtpSession::stopReceiver(bool forceStopSocket)
 {
     // Concurrency protection must be done by caller.
 
@@ -322,8 +342,13 @@ VideoRtpSession::stopReceiver()
     // We need to disable the read operation, otherwise the
     // receiver thread will block since the peer stopped sending
     // RTP packets.
-    if (socketPair_)
-        socketPair_->setReadBlockingMode(false);
+    bool const isSendingVideo = send_.enabled && !send_.onHold;
+    if (socketPair_) {
+        if (forceStopSocket || !isSendingVideo) {
+            socketPair_->setReadBlockingMode(false);
+            socketPair_->stopSendOp();
+        }
+    }
 
     auto ms = receiveThread_->getInfo();
     if (auto ob = recorder_->getStream(ms.name)) {
@@ -331,14 +356,15 @@ VideoRtpSession::stopReceiver()
         recorder_->removeStream(ms);
     }
 
-    receiveThread_->stopLoop();
+    if(forceStopSocket || !isSendingVideo)
+        receiveThread_->stopLoop();
     receiveThread_->stopSink();
 }
 
 void
-VideoRtpSession::start(std::unique_ptr<IceSocket> rtp_sock, std::unique_ptr<IceSocket> rtcp_sock)
+VideoRtpSession::start(std::unique_ptr<dhtnet::IceSocket> rtp_sock, std::unique_ptr<dhtnet::IceSocket> rtcp_sock)
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
     if (not send_.enabled and not receive_.enabled) {
         stop();
@@ -377,8 +403,8 @@ VideoRtpSession::start(std::unique_ptr<IceSocket> rtp_sock, std::unique_ptr<IceS
         return;
     }
 
-    startSender();
     startReceiver();
+    startSender();
 
     if (conference_) {
         if (send_.enabled and not send_.onHold) {
@@ -395,10 +421,13 @@ VideoRtpSession::start(std::unique_ptr<IceSocket> rtp_sock, std::unique_ptr<IceS
 void
 VideoRtpSession::stop()
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
-    stopSender();
-    stopReceiver();
+    stopSender(true);
+    stopReceiver(true);
+
+    if (socketPair_)
+        socketPair_->interrupt();
 
     rtcpCheckerThread_.join();
 
@@ -409,8 +438,6 @@ VideoRtpSession::stop()
     videoBitrateInfo_.videoBitrateCurrent = SystemCodecInfo::DEFAULT_VIDEO_BITRATE;
     storeVideoBitrateInfo();
 
-    if (socketPair_)
-        socketPair_->interrupt();
     socketPair_.reset();
     videoLocal_.reset();
 }
@@ -418,11 +445,7 @@ VideoRtpSession::stop()
 void
 VideoRtpSession::setMuted(bool mute, Direction dir)
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
-
-    // ensure that start has been called before setmuted
-    if (not socketPair_)
-        return;
+    std::lock_guard lock(mutex_);
 
     // Sender
     if (dir == Direction::SEND) {
@@ -472,7 +495,7 @@ VideoRtpSession::setMuted(bool mute, Direction dir)
 void
 VideoRtpSession::forceKeyFrame()
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 #if __ANDROID__
     if (videoLocal_)
         emitSignal<libjami::VideoSignal::RequestKeyFrame>(videoLocal_->getName());
@@ -539,7 +562,7 @@ VideoRtpSession::setupConferenceVideoPipeline(Conference& conference, Direction
 void
 VideoRtpSession::enterConference(Conference& conference)
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
     exitConference();
 
@@ -560,7 +583,7 @@ VideoRtpSession::enterConference(Conference& conference)
 void
 VideoRtpSession::exitConference()
 {
-    std::lock_guard<std::recursive_mutex> lock(mutex_);
+    std::lock_guard lock(mutex_);
 
     if (!conference_)
         return;
@@ -651,12 +674,12 @@ VideoRtpSession::dropProcessing(RTCPInfo* rtcpi)
     if (restartTimer < DELAY_AFTER_RESTART) {
         return;
     }
-
+#ifndef __ANDROID__
     // Do nothing if jitter is more than 1 second
     if (rtcpi->jitter > 1000) {
         return;
     }
-
+#endif
     auto pondLoss = getPonderateLoss(rtcpi->packetLoss);
     auto oldBitrate = videoBitrateInfo_.videoBitrateCurrent;
     int newBitrate = oldBitrate;
@@ -692,9 +715,13 @@ VideoRtpSession::delayProcessing(int br)
     int newBitrate = videoBitrateInfo_.videoBitrateCurrent;
     if (br == 0x6803)
         newBitrate *= 0.85f;
-    else if (br == 0x7378)
-        newBitrate *= 1.05f;
-    else
+    else if (br == 0x7378) {
+        auto now = clock::now();
+        auto msSinceLastDecrease = std::chrono::duration_cast<std::chrono::milliseconds>(
+            now - lastBitrateDecrease);
+        auto increaseCoefficient = std::min(msSinceLastDecrease.count() / 600000.0f + 1.0f, 1.05f);
+        newBitrate *= increaseCoefficient;
+    } else
         return;
 
     setNewBitrate(newBitrate);
@@ -706,6 +733,9 @@ VideoRtpSession::setNewBitrate(unsigned int newBR)
     newBR = std::max(newBR, videoBitrateInfo_.videoBitrateMin);
     newBR = std::min(newBR, videoBitrateInfo_.videoBitrateMax);
 
+    if (newBR < videoBitrateInfo_.videoBitrateCurrent)
+        lastBitrateDecrease = clock::now();
+
     if (videoBitrateInfo_.videoBitrateCurrent != newBR) {
         videoBitrateInfo_.videoBitrateCurrent = newBR;
         storeVideoBitrateInfo();
@@ -730,16 +760,15 @@ VideoRtpSession::setNewBitrate(unsigned int newBR)
 void
 VideoRtpSession::setupVideoBitrateInfo()
 {
-    auto codecVideo = std::static_pointer_cast<jami::AccountVideoCodecInfo>(send_.codec);
+    auto codecVideo = std::static_pointer_cast<jami::SystemVideoCodecInfo>(send_.codec);
     if (codecVideo) {
-        auto& info = codecVideo->systemCodecInfo;
         videoBitrateInfo_ = {
             codecVideo->bitrate,
-            info.minBitrate,
-            info.maxBitrate,
+            codecVideo->minBitrate,
+            codecVideo->maxBitrate,
             codecVideo->quality,
-            info.minQuality,
-            info.maxQuality,
+            codecVideo->minQuality,
+            codecVideo->maxQuality,
             videoBitrateInfo_.cptBitrateChecking,
             videoBitrateInfo_.maxBitrateChecking,
             videoBitrateInfo_.packetLostThreshold,
@@ -753,7 +782,7 @@ VideoRtpSession::setupVideoBitrateInfo()
 void
 VideoRtpSession::storeVideoBitrateInfo()
 {
-    if (auto codecVideo = std::static_pointer_cast<jami::AccountVideoCodecInfo>(send_.codec)) {
+    if (auto codecVideo = std::static_pointer_cast<jami::SystemVideoCodecInfo>(send_.codec)) {
         codecVideo->bitrate = videoBitrateInfo_.videoBitrateCurrent;
         codecVideo->quality = videoBitrateInfo_.videoQualityCurrent;
     }
@@ -769,6 +798,7 @@ VideoRtpSession::processRtcpChecker()
 void
 VideoRtpSession::attachRemoteRecorder(const MediaStream& ms)
 {
+    std::lock_guard lock(mutex_);
     if (!recorder_ || !receiveThread_)
         return;
     if (auto ob = recorder_->addStream(ms)) {
@@ -779,6 +809,7 @@ VideoRtpSession::attachRemoteRecorder(const MediaStream& ms)
 void
 VideoRtpSession::attachLocalRecorder(const MediaStream& ms)
 {
+    std::lock_guard lock(mutex_);
     if (!recorder_ || !videoLocal_ || !Manager::instance().videoPreferences.getRecordPreview())
         return;
     if (auto ob = recorder_->addStream(ms)) {
@@ -789,23 +820,31 @@ VideoRtpSession::attachLocalRecorder(const MediaStream& ms)
 void
 VideoRtpSession::initRecorder()
 {
-	if (!recorder_)
-		return;
+    if (!recorder_)
+        return;
     if (receiveThread_) {
-        receiveThread_->setRecorderCallback(
-            [this](const MediaStream& ms) { attachRemoteRecorder(ms); });
+        receiveThread_->setRecorderCallback([w=weak_from_this()](const MediaStream& ms) {
+            asio::post(*Manager::instance().ioContext(), [w=std::move(w), ms]() {
+                if (auto shared = w.lock())
+                    shared->attachRemoteRecorder(ms);
+            });
+        });
     }
     if (videoLocal_ && !send_.onHold) {
-        videoLocal_->setRecorderCallback(
-            [this](const MediaStream& ms) { attachLocalRecorder(ms); });
+        videoLocal_->setRecorderCallback([w=weak_from_this()](const MediaStream& ms) {
+            asio::post(*Manager::instance().ioContext(), [w=std::move(w), ms]() {
+                if (auto shared = w.lock())
+                    shared->attachLocalRecorder(ms);
+            });
+        });
     }
 }
 
 void
 VideoRtpSession::deinitRecorder()
 {
-	if (!recorder_)
-		return;
+    if (!recorder_)
+        return;
     if (receiveThread_) {
         auto ms = receiveThread_->getInfo();
         if (auto ob = recorder_->getStream(ms.name)) {
