@@ -1,21 +1,18 @@
 /*
- *  Copyright (C) 2021-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Olivier Dion <olivier.dion@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 /* Std */
@@ -211,8 +208,10 @@ install_signal_primitives(void*)
     add_handler<libjami::CallSignal::RecordPlaybackFilepath, const std::string&, const std::string&>(
         handlers, "record-playback-filepath");
 
-    add_handler<libjami::CallSignal::ConferenceCreated, const std::string&, const std::string&>(
-        handlers, "conference-created");
+    add_handler<libjami::CallSignal::ConferenceCreated,
+                const std::string&,
+                const std::string&,
+                const std::string&>(handlers, "conference-created");
 
     add_handler<libjami::CallSignal::ConferenceChanged,
                 const std::string&,
@@ -326,11 +325,6 @@ install_signal_primitives(void*)
                 const std::string&,
                 bool>(handlers, "contact-removed");
 
-    add_handler<libjami::ConfigurationSignal::ExportOnRingEnded,
-                const std::string&,
-                int,
-                const std::string&>(handlers, "export-on-ring-ended");
-
     add_handler<libjami::ConfigurationSignal::NameRegistrationEnded,
                 const std::string&,
                 int,
