@@ -1,15 +1,14 @@
 /*
- *  Copyright (C) 2021-2023 Savoir-faire Linux Inc.
- *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
@@ -25,17 +24,18 @@
 
 #include "manager.h"
 #include "client/videomanager.h"
-#include "connectivity/connectionmanager.h"
 #include "jamidht/jamiaccount.h"
 #include "../../test_runner.h"
 #include "jami.h"
 #include "account_const.h"
 #include "common.h"
 #include "media_const.h"
-#include "video/sinkclient.h"
+#include "media/video/sinkclient.h"
 #include "sip/sipcall.h"
 #include "sip/siptransport.h"
 
+#include <dhtnet/connectionmanager.h>
+
 using namespace libjami::Account;
 using namespace std::literals::chrono_literals;
 
@@ -89,6 +89,7 @@ private:
     void testModeratorMuteUpdateParticipantsInfos();
     void testUnauthorizedMute();
     void testAudioVideoMutedStates();
+    void testMuteStatusAfterAdd();
     void testCreateParticipantsSinks();
     void testMuteStatusAfterRemove();
     void testActiveStatusAfterRemove();
@@ -105,6 +106,7 @@ private:
     void testPropagateRecording();
     void testBrokenParticipantAudioAndVideo();
     void testBrokenParticipantAudioOnly();
+    void testAudioOnlyLeaveLayout();
     void testRemoveConferenceInOneOne();
 
     CPPUNIT_TEST_SUITE(ConferenceTest);
@@ -112,6 +114,7 @@ private:
     CPPUNIT_TEST(testModeratorMuteUpdateParticipantsInfos);
     CPPUNIT_TEST(testUnauthorizedMute);
     CPPUNIT_TEST(testAudioVideoMutedStates);
+    CPPUNIT_TEST(testMuteStatusAfterAdd);
     CPPUNIT_TEST(testCreateParticipantsSinks);
     CPPUNIT_TEST(testMuteStatusAfterRemove);
     CPPUNIT_TEST(testActiveStatusAfterRemove);
@@ -128,6 +131,7 @@ private:
     CPPUNIT_TEST(testPropagateRecording);
     CPPUNIT_TEST(testBrokenParticipantAudioAndVideo);
     CPPUNIT_TEST(testBrokenParticipantAudioOnly);
+    CPPUNIT_TEST(testAudioOnlyLeaveLayout);
     CPPUNIT_TEST(testRemoveConferenceInOneOne);
     CPPUNIT_TEST_SUITE_END();
 
@@ -230,7 +234,7 @@ ConferenceTest::registerSignalHandlers()
             cv.notify_one();
         }));
     confHandlers.insert(libjami::exportable_callback<libjami::CallSignal::ConferenceCreated>(
-        [=](const std::string&, const std::string& conferenceId) {
+        [=](const std::string&, const std::string&, const std::string& conferenceId) {
             confId = conferenceId;
             cv.notify_one();
         }));
@@ -249,7 +253,7 @@ ConferenceTest::registerSignalHandlers()
     confHandlers.insert(libjami::exportable_callback<libjami::CallSignal::OnConferenceInfosUpdated>(
         [=](const std::string&,
             const std::vector<std::map<std::string, std::string>> participantsInfos) {
-            std::lock_guard<std::mutex> lock(pInfosMtx_);
+            std::lock_guard lock(pInfosMtx_);
             pInfos_ = participantsInfos;
             for (const auto& infos : participantsInfos) {
                 if (infos.at("uri").find(bobUri) != std::string::npos) {
@@ -309,20 +313,20 @@ ConferenceTest::startConference(bool audioOnly, bool addDavi)
     JAMI_INFO("Start call between Alice and Bob");
     auto call1 = libjami::placeCallWithMedia(aliceId, bobUri, mediaList);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !bobCall.callId.empty(); }));
-    Manager::instance().answerCall(bobId, bobCall.callId);
+    Manager::instance().acceptCall(bobId, bobCall.callId);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return bobCall.hostState == "CURRENT"; }));
 
     JAMI_INFO("Start call between Alice and Carla");
     auto call2 = libjami::placeCallWithMedia(aliceId, carlaUri, mediaList);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !carlaCall.callId.empty(); }));
-    Manager::instance().answerCall(carlaId, carlaCall.callId);
+    Manager::instance().acceptCall(carlaId, carlaCall.callId);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return carlaCall.hostState == "CURRENT"; }));
 
     JAMI_INFO("Start conference");
     confChanged = false;
     Manager::instance().joinParticipant(aliceId, call1, aliceId, call2);
     // ConfChanged is the signal emitted when the 2 calls will be added to the conference
-    // Also, wait that participants appears in conf info to get all good informations
+    // Also, wait for participants to appear in conf info to get all good information
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] {
         return !confId.empty() && confChanged && !carlaCall.device.empty()
                && !bobCall.device.empty();
@@ -332,9 +336,9 @@ ConferenceTest::startConference(bool audioOnly, bool addDavi)
         JAMI_INFO("Start call between Alice and Davi");
         auto call1 = libjami::placeCallWithMedia(aliceId, daviUri, mediaList);
         CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !daviCall.callId.empty(); }));
-        Manager::instance().answerCall(daviId, daviCall.callId);
+        Manager::instance().acceptCall(daviId, daviCall.callId);
         CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return daviCall.hostState == "CURRENT"; }));
-        Manager::instance().addParticipant(aliceId, call1, aliceId, confId);
+        Manager::instance().addSubCall(aliceId, call1, aliceId, confId);
         CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !daviCall.device.empty(); }));
     }
 }
@@ -426,7 +430,7 @@ ConferenceTest::testAudioVideoMutedStates()
     JAMI_INFO("Start call between Alice and Bob");
     auto call1Id = libjami::placeCallWithMedia(aliceId, bobUri, {});
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !bobCall.callId.empty(); }));
-    Manager::instance().answerCall(bobId, bobCall.callId);
+    Manager::instance().acceptCall(bobId, bobCall.callId);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return bobCall.hostState == "CURRENT"; }));
     auto call1 = aliceAccount->getCall(call1Id);
     call1->muteMedia(libjami::Media::MediaAttributeValue::AUDIO, true);
@@ -435,7 +439,7 @@ ConferenceTest::testAudioVideoMutedStates()
     JAMI_INFO("Start call between Alice and Carla");
     auto call2Id = libjami::placeCallWithMedia(aliceId, carlaUri, {});
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !carlaCall.callId.empty(); }));
-    Manager::instance().answerCall(carlaId, carlaCall.callId);
+    Manager::instance().acceptCall(carlaId, carlaCall.callId);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return carlaCall.hostState == "CURRENT"; }));
 
     auto call2 = aliceAccount->getCall(call2Id);
@@ -459,6 +463,63 @@ ConferenceTest::testAudioVideoMutedStates()
     libjami::unregisterSignalHandlers();
 }
 
+void
+ConferenceTest::testMuteStatusAfterAdd()
+{
+    registerSignalHandlers();
+
+    auto aliceAccount = Manager::instance().getAccount<JamiAccount>(aliceId);
+    auto bobAccount = Manager::instance().getAccount<JamiAccount>(bobId);
+    auto carlaAccount = Manager::instance().getAccount<JamiAccount>(carlaId);
+    auto daviAccount = Manager::instance().getAccount<JamiAccount>(daviId);
+    auto bobUri = bobAccount->getUsername();
+    auto carlaUri = carlaAccount->getUsername();
+    auto daviUri = daviAccount->getUsername();
+
+    std::vector<std::map<std::string, std::string>> mediaList;
+    std::map<std::string, std::string> mediaAttribute
+        = {{libjami::Media::MediaAttributeKey::MEDIA_TYPE,
+            libjami::Media::MediaAttributeValue::AUDIO},
+           {libjami::Media::MediaAttributeKey::ENABLED, TRUE_STR},
+           {libjami::Media::MediaAttributeKey::MUTED, TRUE_STR},
+           {libjami::Media::MediaAttributeKey::SOURCE, ""},
+           {libjami::Media::MediaAttributeKey::LABEL, "audio_0"}};
+    mediaList.emplace_back(mediaAttribute);
+
+    JAMI_INFO("Start call between Alice and Bob");
+    auto call1 = libjami::placeCallWithMedia(aliceId, bobUri, mediaList);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !bobCall.callId.empty(); }));
+    Manager::instance().acceptCall(bobId, bobCall.callId);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return bobCall.hostState == "CURRENT"; }));
+
+    JAMI_INFO("Start call between Alice and Carla");
+    auto call2 = libjami::placeCallWithMedia(aliceId, carlaUri, mediaList);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !carlaCall.callId.empty(); }));
+    Manager::instance().acceptCall(carlaId, carlaCall.callId);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return carlaCall.hostState == "CURRENT"; }));
+
+    JAMI_INFO("Start conference");
+    Manager::instance().joinParticipant(aliceId, call1, aliceId, call2);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !confId.empty(); }));
+
+    JAMI_INFO("Add Davi");
+    auto call3 = libjami::placeCallWithMedia(aliceId, daviUri, {});
+    CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !daviCall.callId.empty(); }));
+    Manager::instance().acceptCall(daviId, daviCall.callId);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return daviCall.hostState == "CURRENT"; }));
+    Manager::instance().addSubCall(aliceId, call3, aliceId, confId);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !daviCall.device.empty(); }));
+
+    auto aliceConf = aliceAccount->getConference(confId);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 5s, [&] {
+        return aliceConf->isMediaSourceMuted(jami::MediaType::MEDIA_AUDIO);
+    }));
+
+    hangupConference();
+
+    libjami::unregisterSignalHandlers();
+}
+
 void
 ConferenceTest::testCreateParticipantsSinks()
 {
@@ -477,9 +538,10 @@ ConferenceTest::testCreateParticipantsSinks()
     CPPUNIT_ASSERT(
         cv.wait_for(lk, 30s, [&] { return pInfos_.size() == expectedNumberOfParticipants; }));
 
-    if (not jami::getVideoDeviceMonitor().getDeviceList().empty()) {
+    auto dm = jami::getVideoDeviceMonitor();
+    if (dm && !dm->getDeviceList().empty()) {
         JAMI_INFO() << "Check sinks if video device available.";
-        std::lock_guard<std::mutex> lock(pInfosMtx_);
+        std::lock_guard lock(pInfosMtx_);
         for (auto& info : pInfos_) {
             auto uri = string_remove_suffix(info["uri"], '@');
             if (uri == bobUri) {
@@ -494,7 +556,7 @@ ConferenceTest::testCreateParticipantsSinks()
         }
     } else {
         JAMI_INFO() << "Check sinks if no video device available.";
-        std::lock_guard<std::mutex> lock(pInfosMtx_);
+        std::lock_guard lock(pInfosMtx_);
         for (auto& info : pInfos_) {
             auto uri = string_remove_suffix(info["uri"], '@');
             if (uri == bobUri) {
@@ -536,9 +598,9 @@ ConferenceTest::testMuteStatusAfterRemove()
 
     auto call2 = libjami::placeCallWithMedia(aliceId, daviUri, {});
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !daviCall.callId.empty(); }));
-    Manager::instance().answerCall(daviId, daviCall.callId);
+    Manager::instance().acceptCall(daviId, daviCall.callId);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return daviCall.hostState == "CURRENT"; }));
-    Manager::instance().addParticipant(aliceId, call2, aliceId, confId);
+    Manager::instance().addSubCall(aliceId, call2, aliceId, confId);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !daviCall.device.empty(); }));
 
     CPPUNIT_ASSERT(cv.wait_for(lk, 5s, [&] { return !daviCall.moderatorMuted.load(); }));
@@ -579,9 +641,9 @@ ConferenceTest::testActiveStatusAfterRemove()
                                              MediaAttribute::mediaAttributesToMediaMaps(
                                                  {defaultAudio}));
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !daviCall.callId.empty(); }));
-    Manager::instance().answerCall(daviId, daviCall.callId);
+    Manager::instance().acceptCall(daviId, daviCall.callId);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return daviCall.hostState == "CURRENT"; }));
-    Manager::instance().addParticipant(aliceId, call2, aliceId, confId);
+    Manager::instance().addSubCall(aliceId, call2, aliceId, confId);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !daviCall.device.empty(); }));
 
     CPPUNIT_ASSERT(cv.wait_for(lk, 5s, [&] { return !daviCall.active.load(); }));
@@ -643,9 +705,9 @@ ConferenceTest::testHandsUp()
 
     auto call2 = libjami::placeCallWithMedia(aliceId, daviUri, {});
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !daviCall.callId.empty(); }));
-    Manager::instance().answerCall(daviId, daviCall.callId);
+    Manager::instance().acceptCall(daviId, daviCall.callId);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return daviCall.hostState == "CURRENT"; }));
-    Manager::instance().addParticipant(aliceId, call2, aliceId, confId);
+    Manager::instance().addSubCall(aliceId, call2, aliceId, confId);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !daviCall.device.empty(); }));
 
     CPPUNIT_ASSERT(cv.wait_for(lk, 5s, [&] { return !daviCall.raisedHand.load(); }));
@@ -696,9 +758,9 @@ ConferenceTest::testJoinCallFromOtherAccount()
     JAMI_INFO("Start call between Alice and Davi");
     auto call1 = libjami::placeCallWithMedia(aliceId, daviUri, {});
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return !daviCall.callId.empty(); }));
-    Manager::instance().answerCall(daviId, daviCall.callId);
+    Manager::instance().acceptCall(daviId, daviCall.callId);
     CPPUNIT_ASSERT(cv.wait_for(lk, 20s, [&] { return daviCall.hostState == "CURRENT"; }));
-    CPPUNIT_ASSERT(Manager::instance().addParticipant(daviId, daviCall.callId, aliceId, confId));
+    CPPUNIT_ASSERT(Manager::instance().addSubCall(daviId, daviCall.callId, aliceId, confId));
     hangupConference();
 
     libjami::unregisterSignalHandlers();
@@ -780,10 +842,10 @@ ConferenceTest::testIsConferenceParticipant()
     startConference();
 
     // is Conference participant should be true for Carla
-    auto participants = aliceAccount->getConference(confId)->getParticipantList();
-    CPPUNIT_ASSERT(participants.size() == 2);
-    auto call1 = *participants.begin();
-    auto call2 = *participants.rbegin();
+    auto subCalls = aliceAccount->getConference(confId)->getSubCalls();
+    CPPUNIT_ASSERT(subCalls.size() == 2);
+    auto call1 = *subCalls.begin();
+    auto call2 = *subCalls.rbegin();
     CPPUNIT_ASSERT(aliceAccount->getCall(call1)->isConferenceParticipant());
     CPPUNIT_ASSERT(aliceAccount->getCall(call2)->isConferenceParticipant());
 
@@ -831,7 +893,7 @@ ConferenceTest::testHostAddRmSecondVideo()
     // Check that alice has two videos attached to the conference
     auto aliceVideos = [&]() {
         int result = 0;
-        std::lock_guard<std::mutex> lock(pInfosMtx_);
+        std::lock_guard lock(pInfosMtx_);
         for (auto i = 0u; i < pInfos_.size(); ++i)
             if (pInfos_[i]["uri"].find(aliceUri) != std::string::npos)
                 result += 1;
@@ -841,7 +903,7 @@ ConferenceTest::testHostAddRmSecondVideo()
 
     // Alice removes her second video
     {
-        std::lock_guard<std::mutex> lock(pInfosMtx_);
+        std::lock_guard lock(pInfosMtx_);
         pInfos_.clear();
     }
     mediaList.pop_back();
@@ -859,9 +921,24 @@ void
 ConferenceTest::testAudioConferenceConfInfo()
 {
     registerSignalHandlers();
+    auto aliceAccount = Manager::instance().getAccount<JamiAccount>(aliceId);
+    auto aliceUri = aliceAccount->getUsername();
 
     startConference(true);
 
+    // Check that alice's video is muted
+    auto aliceVideoMuted = [&]() {
+        int result = 0;
+        std::lock_guard lock(pInfosMtx_);
+        for (auto i = 0u; i < pInfos_.size(); ++i) {
+            if (pInfos_[i]["uri"].find(aliceUri) != std::string::npos
+                && pInfos_[i]["videoMuted"] == "true" && pInfos_[i]["sinkId"] == "host_video_0")
+                result += 1;
+        }
+        return result;
+    };
+    CPPUNIT_ASSERT(cv.wait_for(lk, 10s, [&] { return aliceVideoMuted() == 1; }));
+
     libjami::unregisterSignalHandlers();
 }
 
@@ -899,7 +976,7 @@ ConferenceTest::testParticipantAddRmSecondVideo()
 
     // Check that bob has two videos attached to the conference
     auto bobVideos = [&]() {
-        std::lock_guard<std::mutex> lock(pInfosMtx_);
+        std::lock_guard lock(pInfosMtx_);
         int result = 0;
         for (auto i = 0u; i < pInfos_.size(); ++i)
             if (pInfos_[i]["uri"].find(bobUri) != std::string::npos)
@@ -910,7 +987,7 @@ ConferenceTest::testParticipantAddRmSecondVideo()
 
     // Bob removes his second video
     {
-        std::lock_guard<std::mutex> lock(pInfosMtx_);
+        std::lock_guard lock(pInfosMtx_);
         pInfos_.clear();
     }
     mediaList.pop_back();
@@ -1004,6 +1081,31 @@ ConferenceTest::testBrokenParticipantAudioOnly()
     libjami::unregisterSignalHandlers();
 }
 
+void
+ConferenceTest::testAudioOnlyLeaveLayout()
+{
+    registerSignalHandlers();
+
+    // Start conference with four participants
+    startConference(true, true);
+    auto expectedNumberOfParticipants = 4u;
+
+    // Check participants number
+    CPPUNIT_ASSERT(
+        cv.wait_for(lk, 30s, [&] { return pInfos_.size() == expectedNumberOfParticipants; }));
+
+    // Carla Leave
+    Manager::instance().hangupCall(carlaId, carlaCall.callId);
+
+    // Check participants number
+    // It should have one less participant than in the conference start
+    CPPUNIT_ASSERT(
+        cv.wait_for(lk, 30s, [&] { return expectedNumberOfParticipants - 1 == pInfos_.size(); }));
+
+    hangupConference();
+    libjami::unregisterSignalHandlers();
+}
+
 void
 ConferenceTest::testRemoveConferenceInOneOne()
 {
@@ -1021,4 +1123,4 @@ ConferenceTest::testRemoveConferenceInOneOne()
 } // namespace test
 } // namespace jami
 
-RING_TEST_RUNNER(jami::test::ConferenceTest::name())
+CORE_TEST_RUNNER(jami::test::ConferenceTest::name())
