@@ -1,15 +1,14 @@
 /*
- *  Copyright (C) 2022-2023 Savoir-faire Linux Inc.
- *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
@@ -87,7 +86,7 @@ public:
     std::unique_lock<std::mutex> lk {mtx};
     std::condition_variable cv;
 
-    std::string videoPath = "file://" + std::filesystem::absolute("media/test_video_file.mp4").string();
+    std::string videoPath = "file://" + std::filesystem::absolute("media/data/test_video_file.mp4").string();
 
 private:
     void registerSignalHandlers();
@@ -491,4 +490,4 @@ RecorderTest::testDaemonPreference()
 } // namespace test
 } // namespace jami
 
-RING_TEST_RUNNER(jami::test::RecorderTest::name())
+CORE_TEST_RUNNER(jami::test::RecorderTest::name())
