@@ -1,15 +1,14 @@
 /*
- *  Copyright (C) 2023 Savoir-faire Linux Inc.
- *  Author: Fadi Shehadeh <fadi.shehadeh@savoirfairelinux.com>
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
@@ -23,10 +22,9 @@
 #include "jami.h"
 #include "../common.h"
 #include "jamidht/swarm/swarm_manager.h"
-#include "connectivity/multiplexed_socket.h"
 #include <algorithm>
 
-#include "connectivity/peer_connection.h"
+#include <dhtnet/multiplexed_socket.h>
 #include "nodes.h"
 
 #include <opendht/thread_pool.h>
@@ -58,19 +56,19 @@ struct Counter
 
     void count()
     {
-        std::lock_guard<std::mutex> lock(mutex);
+        std::lock_guard lock(mutex);
         ++added;
         if (added == target)
             cv.notify_one();
     }
     bool wait(std::chrono::steady_clock::duration timeout)
     {
-        std::unique_lock<std::mutex> lock(mutex);
+        std::unique_lock lock(mutex);
         return cv.wait_for(lock, timeout, [&] { return added == target; });
     }
     void wait()
     {
-        std::unique_lock<std::mutex> lock(mutex);
+        std::unique_lock lock(mutex);
         return cv.wait(lock, [&] { return added == target; });
     }
 };
@@ -90,7 +88,7 @@ private:
     std::mt19937_64 rd {dht::crypto::getSeededRandomEngine<std::mt19937_64>()};
     std::mutex channelSocketsMtx_;
     std::vector<NodeId> randomNodeIds;
-    std::map<NodeId, std::map<NodeId, std::shared_ptr<jami::ChannelSocketTest>>> channelSockets_;
+    std::map<NodeId, std::map<NodeId, std::shared_ptr<dhtnet::ChannelSocketTest>>> channelSockets_;
     std::map<NodeId, std::shared_ptr<jami::SwarmManager>> swarmManagers;
     std::map<NodeId, std::set<NodeId>> nodesToConnect;
     std::set<NodeId> messageNode;
@@ -196,7 +194,7 @@ RoutingTableTest::generateSwarmManagers()
     auto total = nNodes + mNodes;
     for (size_t i = 0; i < total; i++) {
         const NodeId& node = randomNodeIds.at(i);
-        auto sm = std::make_shared<SwarmManager>(node);
+        auto sm = std::make_shared<SwarmManager>(node, rd, [](auto) {return false;});
         i >= nNodes ? sm->setMobility(true) : sm->setMobility(false);
         swarmManagers[node] = sm;
     }
@@ -235,13 +233,13 @@ void
 RoutingTableTest::needSocketCallBack(const std::shared_ptr<SwarmManager>& sm)
 {
     sm->needSocketCb_ = [this, wsm = std::weak_ptr<SwarmManager>(sm)](const std::string& nodeId,
-                                                                      auto&& onSocket) {
-        Manager::instance().ioContext()->post([this, wsm, nodeId, onSocket = std::move(onSocket)] {
+                                                                      auto&& onSocket) mutable {
+        asio::post(*Manager::instance().ioContext(), [this, wsm, nodeId, onSocket = std::move(onSocket)] {
             auto sm = wsm.lock();
             if (!sm || sm->isShutdown())
                 return;
-            NodeId node = DeviceId(nodeId);
-            std::lock_guard<std::mutex> lk(channelSocketsMtx_);
+            NodeId node = dhtnet::DeviceId(nodeId);
+            std::lock_guard lk(channelSocketsMtx_);
             if (auto smRemote = getManager(node)) {
                 if (sm->isShutdown()) {
                     std::cout << "SWARMMANAGER " << sm->getId() << " IS SHUTDOWN" << std::endl;
@@ -251,12 +249,12 @@ RoutingTableTest::needSocketCallBack(const std::shared_ptr<SwarmManager>& sm)
                 auto& cstRemote = channelSockets_[node][myId];
                 auto& cstMe = channelSockets_[myId][node];
                 if (!cstRemote) {
-                    cstRemote = std::make_shared<ChannelSocketTest>(myId, "test1", 0);
+                    cstRemote = std::make_shared<dhtnet::ChannelSocketTest>(Manager::instance().ioContext(), myId, "test1", 0);
                 }
                 if (!cstMe) {
-                    cstMe = std::make_shared<ChannelSocketTest>(node, "test1", 0);
+                    cstMe = std::make_shared<dhtnet::ChannelSocketTest>(Manager::instance().ioContext(), node, "test1", 0);
                 }
-                ChannelSocketTest::link(cstMe, cstRemote);
+                dhtnet::ChannelSocketTest::link(cstMe, cstRemote);
                 onSocket(cstMe);
                 smRemote->addChannel(cstRemote);
             }
@@ -296,7 +294,7 @@ RoutingTableTest::testBucketMainFunctions()
 
     NodeInfo InfoNode1(true, sNode2);
 
-    std::set<std::shared_ptr<ChannelSocketInterface>> socketsCheck {sNode1, sNode2};
+    std::set<std::shared_ptr<dhtnet::ChannelSocketInterface>> socketsCheck {sNode1, sNode2};
     std::set<NodeId> nodesCheck {node1, node2};
 
     Bucket bucket(node0);
@@ -502,14 +500,30 @@ RoutingTableTest::testSwarmManagerConnectingNodes_1b()
 {
     std::cout << "\nRunning test: " << __func__ << std::endl;
 
-    SwarmManager sm1(nodeTestIds1.at(0));
-    auto& rt1 = sm1.getRoutingTable();
+    std::vector<NodeId> tryConnect;
+    std::vector<std::string> needSocketNodes;
+    std::condition_variable cv;
+    std::mutex mutex;
+    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds1.at(0), rd, [&](auto n) {
+        std::lock_guard<std::mutex> lk(mutex);
+        tryConnect.emplace_back(n);
+        cv.notify_one();
+        return false;
+    });
+    sm1->needSocketCb_ = [&](const auto& n, auto) {
+        std::lock_guard<std::mutex> lk(mutex);
+        needSocketNodes.emplace_back(n);
+        cv.notify_one();
+    };
+    auto& rt1 = sm1->getRoutingTable();
 
     std::vector<NodeId> toTest(
         {NodeId("053927d831827a9f7e606d4c9c9fe833922c0d35b3960dd2250085f46c0e4f41"),
          NodeId("41a05179e4b3e42c3409b10280bb448d5bbd5ef64784b997d2d1663457bb6ba8")});
 
-    sm1.setKnownNodes(toTest);
+    std::unique_lock lk(mutex);
+    sm1->setKnownNodes(toTest);
+    CPPUNIT_ASSERT(cv.wait_for(lk, 10s, [&](){return tryConnect.size() != 0 && needSocketNodes.size() != 0;}));
 
     CPPUNIT_ASSERT(!rt1.hasConnectingNode(nodeTestIds1.at(0)));
     CPPUNIT_ASSERT(rt1.hasConnectingNode(nodeTestIds1.at(1)));
@@ -522,11 +536,11 @@ RoutingTableTest::testClosestNodes_1b()
 {
     std::cout << "\nRunning test: " << __func__ << std::endl;
 
-    SwarmManager sm1(nodeTestIds1.at(0));
-    SwarmManager sm2(nodeTestIds2.at(0));
+    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds1.at(0), rd, [](auto) {return false;});
+    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds2.at(0), rd, [](auto) {return false;});
 
-    auto& rt1 = sm1.getRoutingTable();
-    auto& rt2 = sm2.getRoutingTable();
+    auto& rt1 = sm1->getRoutingTable();
+    auto& rt2 = sm2->getRoutingTable();
 
     auto bucket1 = rt1.findBucket(nodeTestIds1.at(0));
     auto bucket2 = rt2.findBucket(nodeTestIds2.at(0));
@@ -566,8 +580,8 @@ RoutingTableTest::testClosestNodes_multipleb()
 {
     std::cout << "\nRunning test: " << __func__ << std::endl;
 
-    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds1.at(2));
-    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds1.at(6));
+    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds1.at(2), rd, [](auto) {return false;});
+    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds1.at(6), rd, [](auto) {return false;});
 
     for (size_t i = 0; i < nodeTestChannels1.size(); i++) {
         sm1->addChannel(nodeTestChannels1.at(i));
@@ -596,9 +610,9 @@ RoutingTableTest::testBucketSplit_1n()
 {
     std::cout << "\nRunning test: " << __func__ << std::endl;
 
-    SwarmManager sm1(nodeTestIds2.at(0));
-    SwarmManager sm2(nodeTestIds2.at(nodeTestIds2.size() - 1));
-    SwarmManager sm3(nodeTestIds2.at(nodeTestIds2.size() / 2));
+    SwarmManager sm1(nodeTestIds2.at(0), rd, [](auto) {return false;});
+    SwarmManager sm2(nodeTestIds2.at(nodeTestIds2.size() - 1), rd, [](auto) {return false;});
+    SwarmManager sm3(nodeTestIds2.at(nodeTestIds2.size() / 2), rd, [](auto) {return false;});
 
     auto& rt1 = sm1.getRoutingTable();
     auto& rt2 = sm2.getRoutingTable();
@@ -751,8 +765,8 @@ RoutingTableTest::testSendKnownNodes_1b()
 {
     std::cout << "\nRunning test: " << __func__ << std::endl;
 
-    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds2.at(0));
-    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds3.at(0));
+    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds2.at(0), rd, [](auto) {return false;});
+    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds3.at(0), rd, [](auto) {return false;});
 
     swarmManagers.insert({sm1->getId(), sm1});
     swarmManagers.insert({sm2->getId(), sm2});
@@ -799,8 +813,8 @@ RoutingTableTest::testSendKnownNodes_multipleb()
 {
     std::cout << "\nRunning test: " << __func__ << std::endl;
 
-    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds2.at(8));
-    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds3.at(0));
+    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds2.at(8), rd, [](auto) {return false;});
+    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds3.at(0), rd, [](auto) {return false;});
 
     swarmManagers.insert({sm1->getId(), sm1});
     swarmManagers.insert({sm2->getId(), sm2});
@@ -876,8 +890,8 @@ RoutingTableTest::testMobileNodeAnnouncement()
 {
     std::cout << "\nRunning test: " << __func__ << std::endl;
 
-    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds1.at(0));
-    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds2.at(1));
+    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds1.at(0), rd, [](auto) {return false;});
+    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds2.at(1), rd, [](auto) {return false;});
 
     swarmManagers.insert({sm1->getId(), sm1});
     swarmManagers.insert({sm2->getId(), sm2});
@@ -913,7 +927,7 @@ RoutingTableTest::testMobileNodeSplit()
 {
     std::cout << "\nRunning test: " << __func__ << std::endl;
 
-    SwarmManager sm1(nodeTestIds1.at(0));
+    SwarmManager sm1(nodeTestIds1.at(0), rd, [](auto) {return false;});
 
     auto& rt1 = sm1.getRoutingTable();
 
@@ -969,8 +983,8 @@ RoutingTableTest::testSendMobileNodes()
 {
     std::cout << "\nRunning test: " << __func__ << std::endl;
 
-    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds2.at(8));
-    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds3.at(0));
+    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds2.at(8), rd, [](auto) {return false;});
+    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds3.at(0), rd, [](auto) {return false;});
 
     std::cout << sm1->getId() << std::endl;
 
@@ -1094,8 +1108,8 @@ RoutingTableTest::testRoutingTableForConnectingNode()
     }
     counter.wait();
 
-    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds3.at(0));
-    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds3.at(1));
+    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds3.at(0), rd, [](auto) {return false;});
+    auto sm2 = std::make_shared<SwarmManager>(nodeTestIds3.at(1), rd, [](auto) {return false;});
 
     swarmManagers.insert({sm1->getId(), sm1});
     swarmManagers.insert({sm2->getId(), sm2});
@@ -1139,7 +1153,7 @@ RoutingTableTest::testRoutingTableForShuttingNode()
 
     counter.wait();
 
-    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds3.at(0));
+    auto sm1 = std::make_shared<SwarmManager>(nodeTestIds3.at(0), rd, [](auto) {return false;});
     auto sm1Id = sm1->getId();
 
     swarmManagers.emplace(sm1->getId(), sm1);
@@ -1209,7 +1223,7 @@ RoutingTableTest::testRoutingTableForMassShuttingsNodes()
 
     // ADDING NEW NODES TO NETWORK
     for (size_t i = 0; i < nodeTestIds1.size(); i++) {
-        auto sm = std::make_shared<SwarmManager>(nodeTestIds1.at(i));
+        auto sm = std::make_shared<SwarmManager>(nodeTestIds1.at(i), rd, [](auto) {return false;});
         auto smId = sm->getId();
         swarmManagers.emplace(smId, sm);
         needSocketCallBack(sm);
@@ -1223,7 +1237,7 @@ RoutingTableTest::testRoutingTableForMassShuttingsNodes()
     CPPUNIT_ASSERT_EQUAL(swarmManagers.size(), discoveredNodes.size());
 
     // SHUTTING DOWN ADDED NODES
-    std::lock_guard<std::mutex> lk(channelSocketsMtx_);
+    std::lock_guard lk(channelSocketsMtx_);
     for (auto& nodes : nodeTestIds1) {
         auto it = swarmManagers.find(nodes);
         if (it != swarmManagers.end()) {
@@ -1287,7 +1301,7 @@ RoutingTableTest::testSwarmManagersWMobileModes()
 
     // Shutting down Mobile Nodes
     {
-        std::lock_guard<std::mutex> lk(channelSocketsMtx_);
+        std::lock_guard lk(channelSocketsMtx_);
         for (auto it = swarmManagers.begin(); it != swarmManagers.end();) {
             if (it->second->isMobile()) {
                 it->second->shutdown();
@@ -1318,4 +1332,4 @@ RoutingTableTest::testSwarmManagersWMobileModes()
 
 }; // namespace test
 } // namespace jami
-RING_TEST_RUNNER(jami::test::RoutingTableTest::name())
+CORE_TEST_RUNNER(jami::test::RoutingTableTest::name())
