@@ -1,15 +1,14 @@
 /*
- *  Copyright (C) 2024 Savoir-faire Linux Inc.
- *  Author: Fadi Shehadeh <fadi.shehadeh@savoirfairelinux.com>
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
@@ -80,12 +79,12 @@ struct Counter
     }
     bool wait(std::chrono::steady_clock::duration timeout)
     {
-        std::unique_lock<std::mutex> lock(mutex);
+        std::unique_lock lock(mutex);
         return cv.wait_for(lock, timeout, [&] { return added == target; });
     }
     void wait()
     {
-        std::unique_lock<std::mutex> lock(mutex);
+        std::unique_lock lock(mutex);
         return cv.wait(lock, [&] { return added == target; });
     }
 };
@@ -160,7 +159,7 @@ SwarmMessageSpread::generateSwarmManagers()
 {
     for (size_t i = 0; i < nNodes; i++) {
         const NodeId node = Hash<32>::getRandom();
-        auto sm = std::make_shared<SwarmManager>(node, rd, std::move([](auto) {return false;}));
+        auto sm = std::make_shared<SwarmManager>(node, rd, [](auto) {return false;});
         swarmManagers[node] = sm;
         randomNodeIds.emplace_back(node);
         swarmManagersShuffled.emplace_back(sm);
@@ -284,7 +283,7 @@ SwarmMessageSpread::needSocketCallBack(const std::shared_ptr<SwarmManager>& sm)
                 NodeId node = dhtnet::DeviceId(nodeId);
                 if (auto smRemote = getManager(node)) {
                     auto myId = sm->getId();
-                    std::unique_lock<std::mutex> lk(channelSocketsMtx_);
+                    std::unique_lock lk(channelSocketsMtx_);
                     auto& cstRemote = channelSockets_[node][myId];
                     auto& cstMe = channelSockets_[myId][node];
                     if (cstMe.second && cstMe.first)
@@ -419,7 +418,7 @@ SwarmMessageSpread::testWriteMessage()
         }
     }
 
-    std::unique_lock<std::mutex> lk(channelSocketsMtx_);
+    std::unique_lock lk(channelSocketsMtx_);
     bool ok = channelSocketsCv_.wait_for(lk, 1200s, [&] {
         std::cout << "\r"
                   << "Size of Received " << numberTimesReceived.size();
@@ -475,4 +474,4 @@ SwarmMessageSpread::testWriteMessage()
 
 }; // namespace test
 } // namespace jami
-RING_TEST_RUNNER(jami::test::SwarmMessageSpread::name())
+CORE_TEST_RUNNER(jami::test::SwarmMessageSpread::name())
