@@ -1,9 +1,5 @@
 /*
- * Copyright (C) 2015-2024 Savoir-faire Linux Inc.
- * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
- * Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
+ * Copyright (C) 2015-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,11 +17,15 @@
 
 #include "mainapplication.h"
 
+#include "global.h"
 #include "qmlregister.h"
 #include "appsettingsmanager.h"
 #include "connectivitymonitor.h"
 #include "systemtray.h"
-#include "videoprovider.h"
+#include "previewengine.h"
+#include "crashreporter.h"
+
+#include <QWKQuick/qwkquickglobal.h>
 
 #include <QAction>
 #include <QCommandLineParser>
@@ -38,10 +38,6 @@
 #include <QTranslator>
 #include <QLibraryInfo>
 #include <QQuickWindow>
-#include <QLoggingCategory>
-
-#include <locale.h>
-#include <thread>
 
 #ifdef Q_OS_WIN
 #include <windows.h>
@@ -52,7 +48,7 @@
 #include "dbuserrorhandler.h"
 #endif
 
-Q_LOGGING_CATEGORY(app_, "app_")
+Q_LOGGING_CATEGORY(clientLog, "client")
 
 static const QtMessageHandler QT_DEFAULT_MESSAGE_HANDLER = qInstallMessageHandler(0);
 
@@ -62,23 +58,30 @@ messageHandler(QtMsgType type, const QMessageLogContext& context, const QString&
     const static std::string fmt[5] = {"DBG", "WRN", "CRT", "FTL", "INF"};
     const QByteArray localMsg = msg.toUtf8();
     const auto ts = QString::number(QDateTime::currentMSecsSinceEpoch());
+    const auto tid = QString::number(reinterpret_cast<quintptr>(QThread::currentThreadId()), 16);
 
     QString fileLineInfo = "";
+    const auto isQml = QString(context.category) == QLatin1String("qml");
 #ifdef QT_DEBUG
-    // In debug mode, always include file and line info.
-    fileLineInfo = QString("[%1:%2]").arg(context.file ? context.file : "unknown",
-                                          context.line ? QString::number(context.line) : "0");
+    // In debug mode, always include file URI (including line info).
+    // Only do this when the level Info/Debug, as it is already included in the constructed
+    // message for the other levels.
+    if (type == QtDebugMsg || type == QtInfoMsg || !isQml) {
+        auto fileName = isQml ? context.file : QUrl::fromLocalFile(context.file).toString();
+        fileLineInfo = QString(" %1:%2").arg(!fileName.isEmpty() ? fileName : "unknown",
+                                             context.line ? QString::number(context.line) : "0");
+    }
 #else
     // In release mode, include file and line info only for QML category which will always
     // be available and provide a link to the source code in QtCreator.
-    if (QString(context.category) == QLatin1String("qml")) {
+    if (isQml) {
         fileLineInfo = QString("[%1:%2]").arg(context.file ? context.file : "unknown",
                                               context.line ? QString::number(context.line) : "0");
     }
 #endif
 
-    const auto fmtMsg = QString("[%1][%2]%3: %4")
-                            .arg(ts, fmt[type].c_str(), fileLineInfo, localMsg.constData());
+    const auto fmtMsg = QString("[%1][%2][%3]:%4 %5")
+                            .arg(ts, fmt[type].c_str(), tid, fileLineInfo, localMsg.constData());
 
     (*QT_DEFAULT_MESSAGE_HANDLER)(type, context, fmtMsg);
 }
@@ -138,11 +141,10 @@ ScreenInfo::onPhysicalDotsPerInchChanged()
 
 MainApplication::MainApplication(int& argc, char** argv)
     : QApplication(argc, argv)
-    , isCleanupped(false)
 {
     const char* qtVersion = qVersion();
     if (strncmp(qtVersion, QT_VERSION_STR, strnlen(qtVersion, sizeof qtVersion)) != 0) {
-        qCFatal(app_) << "Qt build version mismatch!" << QT_VERSION_STR;
+        C_FATAL << "Qt build version mismatch!" << QT_VERSION_STR;
     }
 
     parseArguments();
@@ -152,8 +154,12 @@ MainApplication::MainApplication(int& argc, char** argv)
     // without using `qt.*=false`. It may be useful for debugging Qt/QtQuick issues.
     QLoggingCategory::setFilterRules("\n"
                                      "*.debug=true\n"
+                                     "libclient.debug=false\n"
                                      "qt.*=false\n"
                                      "qml.debug=false\n"
+                                     "default.debug=false\n"
+                                     "client.debug=false\n"
+                                     "spellcheck.debug=false\n"
                                      "\n");
     // These can be set in the environment as well.
     // e.g. QT_LOGGING_RULES="*.debug=false;qml.debug=true"
@@ -166,27 +172,36 @@ MainApplication::MainApplication(int& argc, char** argv)
     // the logging features.
     qInstallMessageHandler(messageHandler);
 
-    QObject::connect(this, &QApplication::aboutToQuit, this, &MainApplication::cleanup);
-
-    qCInfo(app_) << "Using Qt runtime version:" << qtVersion;
+    C_INFO << "Using Qt runtime version:" << qtVersion;
 }
 
 MainApplication::~MainApplication()
 {
     engine_.reset();
     lrcInstance_.reset();
+
+    // Allow the crash reporter to do implementation-specific cleanup before the application exits.
+    delete crashReporter_;
 }
 
 bool
 MainApplication::init()
 {
+    // Let's make sure we can provide postmortem debugging information prior
+    // to any other initialization. This won't do anything if crashpad isn't
+    // enabled.
+    settingsManager_ = new AppSettingsManager(this);
+    crashReporter_ = new CrashReporter(settingsManager_, this);
+
     // This 2-phase initialisation prevents ephemeral instances from
-    // performing unnecessary tasks, like initializing the webengine.
+    // performing unnecessary tasks, like initializing the WebEngine.
     engine_.reset(new QQmlApplicationEngine(this));
 
+    QWK::registerTypes(engine_.get());
+
     connectivityMonitor_ = new ConnectivityMonitor(this);
-    settingsManager_ = new AppSettingsManager(this);
     systemTray_ = new SystemTray(settingsManager_, this);
+    previewEngine_ = new PreviewEngine(connectivityMonitor_, this);
 
     // These should should be QueuedConnection to ensure that the
     // they are executed after the QML engine has been initialized,
@@ -254,18 +269,6 @@ MainApplication::init()
     // The presence of start URI should override the startMinimized setting for this instance.
     set_startMinimized(startMinimizedSetting && runOptions_[Option::StartUri].isNull());
 
-#ifdef WITH_WEBENGINE
-    engine_.get()->rootContext()->setContextProperty("WITH_WEBENGINE", QVariant(true));
-#else
-    engine_.get()->rootContext()->setContextProperty("WITH_WEBENGINE", QVariant(false));
-#endif
-
-#ifdef APPSTORE
-    engine_.get()->rootContext()->setContextProperty("APPSTORE", QVariant(true));
-#else
-    engine_.get()->rootContext()->setContextProperty("APPSTORE", QVariant(false));
-#endif
-
     initQmlLayer();
 
     settingsManager_->setValue(Settings::Key::StartMinimized,
@@ -288,10 +291,10 @@ MainApplication::handleUriAction(const QString& arg)
     QString uri {};
     if (arg.isEmpty() && !runOptions_[Option::StartUri].isNull()) {
         uri = runOptions_[Option::StartUri].toString();
-        qCDebug(app_) << "URI action invoked by run option" << uri;
+        C_DBG << "URI action invoked by run option" << uri;
     } else if (!arg.isEmpty()) {
         uri = arg;
-        qCDebug(app_) << "URI action invoked by secondary instance" << uri;
+        C_DBG << "URI action invoked by secondary instance" << uri;
         Q_EMIT searchAndSelect(uri.replace("jami:", ""));
     }
 }
@@ -302,30 +305,7 @@ MainApplication::initLrc(const QString& downloadUrl,
                          bool debugMode,
                          bool muteDaemon)
 {
-    /*
-     * Init mainwindow and finish splash when mainwindow shows up.
-     */
-    std::atomic_bool isMigrating(false);
-    lrcInstance_.reset(new LRCInstance(
-        [this, &isMigrating] {
-            /*
-             * TODO: splash screen for account migration.
-             */
-            isMigrating = true;
-            while (isMigrating) {
-                this->processEvents();
-            }
-        },
-        [&isMigrating] {
-            while (!isMigrating) {
-                std::this_thread::sleep_for(std::chrono::milliseconds(10));
-            }
-            isMigrating = false;
-        },
-        downloadUrl,
-        cm,
-        debugMode,
-        muteDaemon));
+    lrcInstance_.reset(new LRCInstance(downloadUrl, cm, debugMode, muteDaemon));
     lrcInstance_->subscribeToDebugReceived();
 }
 
@@ -339,49 +319,59 @@ MainApplication::parseArguments()
         }
     }
 
-    QCommandLineParser parser;
-    parser.addHelpOption();
-    parser.addVersionOption();
+    parser_.addHelpOption();
+    parser_.addVersionOption();
 
     QCommandLineOption webDebugOption(QStringList() << "remote-debugging-port",
                                       "Web debugging port.",
                                       "port");
-    parser.addOption(webDebugOption);
+    parser_.addOption(webDebugOption);
 
     QCommandLineOption minimizedOption({"m", "minimized"}, "Start minimized.");
-    parser.addOption(minimizedOption);
+    parser_.addOption(minimizedOption);
 
     QCommandLineOption debugOption({"d", "debug"}, "Debug out.");
-    parser.addOption(debugOption);
+    parser_.addOption(debugOption);
 
     QCommandLineOption logFileOption({"f", "file"}, "Debug to <file>.", "file");
-    parser.addOption(logFileOption);
+    parser_.addOption(logFileOption);
 
 #ifdef Q_OS_WINDOWS
     QCommandLineOption updateUrlOption({"u", "url"}, "<url> for debugging version queries.", "url");
-    parser.addOption(updateUrlOption);
+    parser_.addOption(updateUrlOption);
 
 #endif
     QCommandLineOption terminateOption({"t", "term"}, "Terminate all instances.");
-    parser.addOption(terminateOption);
+    parser_.addOption(terminateOption);
 
     QCommandLineOption muteDaemonOption({"q", "quiet"}, "Mute daemon logging. (only if debug)");
-    parser.addOption(muteDaemonOption);
+    parser_.addOption(muteDaemonOption);
 
-    parser.process(*this);
+#ifdef QT_DEBUG
+    //  In debug mode, add an option to test a specific QML component via its name.
+    //  e.g. ./jami --test AccountComboBox
+    parser_.addOption(QCommandLineOption("test", "Test a QML component via its name.", "uri"));
+    // We may need to force the test window dimensions in the case that the component to test
+    // does not specify its own dimensions and is dependent on parent/sibling dimensions.
+    // e.g. ./jami --test AccountComboBox -w 200
+    parser_.addOption(QCommandLineOption("width", "Width for the test window.", "width"));
+    parser_.addOption(QCommandLineOption("height", "Height for the test window.", "height"));
+#endif
 
-    runOptions_[Option::StartMinimized] = parser.isSet(minimizedOption);
-    runOptions_[Option::Debug] = parser.isSet(debugOption);
-    if (parser.isSet(logFileOption)) {
-        auto logFileValue = parser.value(logFileOption);
+    parser_.process(*this);
+
+    runOptions_[Option::StartMinimized] = parser_.isSet(minimizedOption);
+    runOptions_[Option::Debug] = parser_.isSet(debugOption);
+    if (parser_.isSet(logFileOption)) {
+        auto logFileValue = parser_.value(logFileOption);
         auto logFile = logFileValue.isEmpty() ? Utils::getDebugFilePath() : logFileValue;
         qputenv("JAMI_LOG_FILE", logFile.toStdString().c_str());
     }
 #ifdef Q_OS_WINDOWS
-    runOptions_[Option::UpdateUrl] = parser.value(updateUrlOption);
+    runOptions_[Option::UpdateUrl] = parser_.value(updateUrlOption);
 #endif
-    runOptions_[Option::TerminationRequested] = parser.isSet(terminateOption);
-    runOptions_[Option::MuteDaemon] = parser.isSet(muteDaemonOption);
+    runOptions_[Option::TerminationRequested] = parser_.isSet(terminateOption);
+    runOptions_[Option::MuteDaemon] = parser_.isSet(muteDaemonOption);
 }
 
 void
@@ -397,6 +387,35 @@ MainApplication::setApplicationFont()
     setFont(font);
 }
 
+QString
+findResource(const QString& targetBasename, const QString& basePath = ":/")
+{
+    QDir dir(basePath);
+    // List all entries in the directory excluding special entries '.' and '..'
+    QStringList entries = dir.entryList(QDir::Files | QDir::Dirs | QDir::NoDotAndDotDot,
+                                        QDir::DirsFirst);
+
+    Q_FOREACH (const QString& entry, entries) {
+        QString fullPath = basePath + "/" + entry;
+        QFileInfo fileInfo(fullPath);
+
+        if (fileInfo.isDir()) {
+            // Recursively search in subdirectories
+            QString found = findResource(targetBasename, fullPath);
+            if (!found.isEmpty()) {
+                return found; // Return the first match found in any subdirectory
+            }
+        } else if (fileInfo.isFile()
+                   && fileInfo.fileName().contains(targetBasename, Qt::CaseInsensitive)) {
+            // Match found, return the full path but remove the leading ":/".
+            return fileInfo.absoluteFilePath().mid(2);
+        }
+    }
+
+    // No match found in this directory or its subdirectories
+    return QString();
+}
+
 void
 MainApplication::initQmlLayer()
 {
@@ -406,20 +425,46 @@ MainApplication::initQmlLayer()
                          systemTray_,
                          settingsManager_,
                          connectivityMonitor_,
+                         previewEngine_,
                          &screenInfo_,
                          this);
 
-    auto videoProvider = new VideoProvider(lrcInstance_->avModel(), this);
-    engine_->rootContext()->setContextProperty("videoProvider", videoProvider);
+    // Register the crash reporter as a context property in the QML engine.
+    engine_->rootContext()->setContextProperty("crashReporter", crashReporter_);
 
-    engine_->load(QUrl(QStringLiteral("qrc:/MainApplicationWindow.qml")));
-    qCWarning(app_) << "Main window loaded using" << getRenderInterfaceString();
+    QUrl url = QStringLiteral("qrc:/MainApplicationWindow.qml");
+#ifdef QT_DEBUG
+    if (parser_.isSet("test")) {
+        // List the QML files in the project source tree.
+        const auto targetTestComponent = findResource(parser_.value("test"));
+        if (targetTestComponent.isEmpty()) {
+            C_FATAL << "Failed to find QML component:" << parser_.value("test");
+        }
+        engine_->rootContext()->setContextProperty("testComponentURI", targetTestComponent);
+        // Log the width and height values for the test window.
+        const auto testWidth = parser_.isSet("width") ? parser_.value("width").toInt() : 0;
+        const auto testHeight = parser_.isSet("height") ? parser_.value("height").toInt() : 0;
+        engine_->rootContext()->setContextProperty("testWidth", testWidth);
+        engine_->rootContext()->setContextProperty("testHeight", testHeight);
+        url = QStringLiteral("qrc:/ComponentTestWindow.qml");
+    }
+#endif
+    QObject::connect(
+        engine_.get(),
+        &QQmlApplicationEngine::objectCreationFailed,
+        this,
+        [url]() { C_FATAL << "Failed to load QML component:" << url; },
+        Qt::QueuedConnection);
+    engine_->load(url);
+
+    // Report the render interface used.
+    C_INFO << "Main window loaded using" << getRenderInterfaceString();
 }
 
 void
 MainApplication::initSystray()
 {
-    systemTray_->setIcon(QIcon(":/images/jami.svg"));
+    systemTray_->setIcon(QIcon(":/images/net.jami.Jami.svg"));
 
     QMenu* menu {nullptr};
     // If there was a previous menu, reuse it, otherwise create a new one.
@@ -466,17 +511,6 @@ MainApplication::initSystray()
     systemTray_->show();
 }
 
-void
-MainApplication::cleanup()
-{
-    // In Qt 6.5, QApplication::exit(0) will signal aboutToQuit, and aboutToQuit is connected to cleanup
-    // TODO: delete cleanup.
-    if (!isCleanupped) {
-        isCleanupped = true;
-        QApplication::exit(0);
-    }
-}
-
 void
 MainApplication::setEventFilter()
 {
