@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2023 Savoir-faire Linux Inc.
+ * Copyright (C) 2019-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,8 @@ translateErrorCode(QNetworkReply::NetworkError error)
     static auto inRange = [](int value, int min, int max) -> bool {
         return (value >= min && value <= max);
     };
+    if (error == QNetworkReply::OperationCanceledError)
+        return NetworkManager::CANCELED;
     if (inRange(error, 1, 199))
         return NetworkManager::NETWORK_ERROR;
     if (inRange(error, 201, 201))
@@ -159,7 +161,7 @@ NetworkManager::downloadFile(const QUrl& url,
     if (!file->open(QIODevice::WriteOnly)) {
         Q_EMIT errorOccurred(GetError::ACCESS_DENIED);
         files_.remove(uuid);
-        qWarning() << Q_FUNC_INFO << "Could not open file for writing";
+        qWarning() << Q_FUNC_INFO << "An error occurred while opening file for writing.";
         return 0;
     }
 
@@ -187,8 +189,8 @@ NetworkManager::downloadFile(const QUrl& url,
             [this, uuid, reply](QNetworkReply::NetworkError error) {
                 reply->disconnect();
                 resetDownload(uuid);
-                qWarning() << Q_FUNC_INFO
-                           << QMetaEnum::fromType<QNetworkReply::NetworkError>().valueToKey(error);
+                qDebug() << Q_FUNC_INFO
+                         << QMetaEnum::fromType<QNetworkReply::NetworkError>().valueToKey(error);
                 Q_EMIT errorOccurred(translateErrorCode(error));
             });
 
@@ -215,7 +217,9 @@ void
 NetworkManager::cancelDownload(int replyId)
 {
     if (downloadReplies_.value(replyId) != NULL) {
-        Q_EMIT errorOccurred(GetError::CANCELED);
+        // Aborting the download will trigger the emission of a QNetworkReply error
+        // (`QNetworkReply::OperationCanceledError`), and be caught, translated to our internal
+        // error `GetError::CANCELED`, and re-emitted.
         downloadReplies_[replyId]->abort();
         resetDownload(replyId);
     }
