@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2014-2022 Savoir-faire Linux Inc.
+ *  Copyright (C) 2014-2025 Savoir-faire Linux Inc.
  *  Author(s) : Adrien Béraud <adrien.beraud@savoirfairelinux.com>
  *              Simon Désaulniers <simon.desaulniers@savoirfairelinux.com>
  *
@@ -20,10 +20,12 @@
 #include "network_engine.h"
 #include "request.h"
 #include "default_types.h"
-#include "log_enable.h"
+#include "logger.h"
 #include "parsed_message.h"
 
 #include <msgpack.hpp>
+#include <chrono>
+#include <string_view>
 
 namespace dht {
 namespace net {
@@ -41,7 +43,8 @@ constexpr std::chrono::seconds NetworkEngine::UDP_REPLY_TIME;
 constexpr std::chrono::seconds NetworkEngine::RX_MAX_PACKET_TIME;
 constexpr std::chrono::seconds NetworkEngine::RX_TIMEOUT;
 
-const std::string NetworkEngine::my_v {"RNG1"};
+/* OpenDHT User Agent (UA) */
+constexpr std::string_view OPENDHT_UA {"o2"};
 
 static constexpr uint8_t v4prefix[16] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0xFF, 0xFF, 0, 0, 0, 0};
 
@@ -140,7 +143,7 @@ NetworkEngine::tellListenerRefreshed(const Sp<Node>& n, Tid socket_id, const Inf
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
 
-    pk.pack_map(4 + (version >= 1 ? 1 : 0) + (config.network?1:0));
+    pk.pack_map(4 + (version >= 1 ? 1 : 0) + (config.network?1:0)+(config.is_client?1:0));
 
     pk.pack(version >= 1 ? KEY_A : KEY_U);
         pk.pack_map(1 + (version >= 1 ? 1 : 0) + (not values.empty()?1:0) + (not token.empty()?1:0));
@@ -159,10 +162,13 @@ NetworkEngine::tellListenerRefreshed(const Sp<Node>& n, Tid socket_id, const Inf
         }
 
     pk.pack(KEY_Y); pk.pack(version >= 1 ? KEY_Q : KEY_R);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     if (version >= 1) {
         Tid tid (n->getNewTid());
@@ -191,7 +197,7 @@ NetworkEngine::tellListenerExpired(const Sp<Node>& n, Tid socket_id, const InfoH
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
 
-    pk.pack_map(4 + (version >= 1 ? 1 : 0) + (config.network?1:0));
+    pk.pack_map(4 + (version >= 1 ? 1 : 0) + (config.network?1:0)+(config.is_client?1:0));
 
     pk.pack(version >= 1 ? KEY_A : KEY_U);
         pk.pack_map(1 + (version >= 1 ? 1 : 0) + (not values.empty()?1:0) + (not token.empty()?1:0));
@@ -210,10 +216,13 @@ NetworkEngine::tellListenerExpired(const Sp<Node>& n, Tid socket_id, const InfoH
         }
 
     pk.pack(KEY_Y); pk.pack(version >= 1 ? KEY_Q : KEY_R);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     if (version >= 1) {
         Tid tid (n->getNewTid());
@@ -375,7 +384,6 @@ NetworkEngine::isMartian(const SockAddr& addr)
         const auto& sin6 = addr.getIPv6();
         const uint8_t* address = (const uint8_t*)&sin6.sin6_addr;
         return address[0] == 0xFF ||
-              (address[0] == 0xFE && (address[1] & 0xC0) == 0x80) ||
                memcmp(address, InfoHash::zero().data(), 16) == 0 ||
                memcmp(address, v4prefix,      12) == 0;
     }
@@ -518,8 +526,13 @@ NetworkEngine::process(std::unique_ptr<ParsedMessage>&& msg, const SockAddr& fro
             throw DhtProtocolException {DhtProtocolException::UNKNOWN_TID, "Can't find socket", msg->id};
         node->received(now, {});
         onNewNode(node, 2);
-        deserializeNodes(*msg, from);
-        rsocket->on_receive(node, std::move(*msg));
+        try {
+            deserializeNodes(*msg, from);
+            rsocket->on_receive(node, std::move(*msg));
+        } catch (const DhtProtocolException& e) {
+            if (logger_)
+                logger_->w("Can't deserialize nodes %s", e.what());
+        }
     }
     else if (msg->type == MessageType::Error or msg->type == MessageType::Reply) {
         auto rsocket = node->getSocket(msg->tid);
@@ -582,13 +595,22 @@ NetworkEngine::process(std::unique_ptr<ParsedMessage>&& msg, const SockAddr& fro
                     r.node->authSuccess();
                 }
                 r.reply_time = scheduler.time();
-
-                deserializeNodes(*msg, from);
-                r.setDone(std::move(*msg));
+                try {
+                    deserializeNodes(*msg, from);
+                    r.setDone(std::move(*msg));
+                } catch (const DhtProtocolException& e) {
+                    if (logger_)
+                        logger_->w("Can't deserialize nodes %s", e.what());
+                }
                 break;
             } else { /* request socket data */
-                deserializeNodes(*msg, from);
-                rsocket->on_receive(node, std::move(*msg));
+                try {
+                    deserializeNodes(*msg, from);
+                    rsocket->on_receive(node, std::move(*msg));
+                } catch (const DhtProtocolException& e) {
+                    if (logger_)
+                        logger_->w("Can't deserialize nodes %s", e.what());
+                }
             }
             break;
         default:
@@ -702,7 +724,7 @@ NetworkEngine::sendPing(const Sp<Node>& node, RequestCb&& on_done, RequestExpire
     Tid tid (node->getNewTid());
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(5+(config.network?1:0));
+    pk.pack_map(5+(config.network?1:0)+(config.is_client?1:0));
 
     pk.pack(KEY_A); pk.pack_map(1);
      pk.pack(KEY_REQ_ID); pk.pack(myid);
@@ -710,10 +732,13 @@ NetworkEngine::sendPing(const Sp<Node>& node, RequestCb&& on_done, RequestExpire
     pk.pack(KEY_Q); pk.pack(QUERY_PING);
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y); pk.pack(KEY_Q);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     auto req = std::make_shared<Request>(MessageType::Ping, tid, node,
         Blob(buffer.data(), buffer.data() + buffer.size()),
@@ -739,7 +764,7 @@ void
 NetworkEngine::sendPong(const SockAddr& addr, Tid tid) {
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(4+(config.network?1:0));
+    pk.pack_map(4+(config.network?1:0)+(config.is_client?1:0));
 
     pk.pack(KEY_R); pk.pack_map(2);
       pk.pack(KEY_REQ_ID); pk.pack(myid);
@@ -747,10 +772,13 @@ NetworkEngine::sendPong(const SockAddr& addr, Tid tid) {
 
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y); pk.pack(KEY_R);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     send(addr, buffer.data(), buffer.size());
 }
@@ -761,7 +789,7 @@ NetworkEngine::sendFindNode(const Sp<Node>& n, const InfoHash& target, want_t wa
     Tid tid (n->getNewTid());
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(5+(config.network?1:0));
+    pk.pack_map(5+(config.network?1:0)+(config.is_client?1:0));
 
     pk.pack(KEY_A); pk.pack_map(2 + (want>0?1:0));
       pk.pack(KEY_REQ_ID);     pk.pack(myid);
@@ -776,10 +804,13 @@ NetworkEngine::sendFindNode(const Sp<Node>& n, const InfoHash& target, want_t wa
     pk.pack(KEY_Q); pk.pack(QUERY_FIND);
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y); pk.pack(KEY_Q);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     auto req = std::make_shared<Request>(MessageType::FindNode, tid, n,
         Blob(buffer.data(), buffer.data() + buffer.size()),
@@ -806,7 +837,7 @@ NetworkEngine::sendGetValues(const Sp<Node>& n, const InfoHash& info_hash, const
     Tid tid (n->getNewTid());
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(5+(config.network?1:0));
+    pk.pack_map(5+(config.network?1:0)+(config.is_client?1:0));
 
     unsigned sendQuery = (not query.where.empty() or not query.select.empty()) ? 1 : 0;
     unsigned sendWant = (want > 0) ? 1 : 0;
@@ -829,11 +860,14 @@ NetworkEngine::sendGetValues(const Sp<Node>& n, const InfoHash& info_hash, const
     pk.pack(KEY_Q); pk.pack(QUERY_GET);
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y); pk.pack(KEY_Q);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
-
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
+    
     auto req = std::make_shared<Request>(MessageType::GetValues, tid, n,
         Blob(buffer.data(), buffer.data() + buffer.size()),
         [=](const Request& req_status, ParsedMessage&& msg) { /* on done */
@@ -950,10 +984,13 @@ NetworkEngine::sendValueParts(Tid tid, const std::vector<Blob>& svals, const Soc
             end = std::min(start + MTU, v.size());
             buffer.clear();
             msgpack::packer<msgpack::sbuffer> pk(&buffer);
-            pk.pack_map(3+(config.network?1:0));
+            pk.pack_map(3+(config.network?1:0)+(config.is_client?1:0));
             if (config.network) {
                 pk.pack(KEY_NETID); pk.pack(config.network);
             }
+            if (config.is_client) {
+                pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+            }
             pk.pack(KEY_Y); pk.pack(KEY_V);
             pk.pack(KEY_TID); pk.pack(tid);
             pk.pack(KEY_V); pk.pack_map(1);
@@ -974,7 +1011,7 @@ NetworkEngine::sendNodesValues(const SockAddr& addr, Tid tid, const Blob& nodes,
 {
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(4+(config.network?1:0));
+    pk.pack_map(4+(config.network?1:0)+(config.is_client?1:0));
 
     pk.pack(KEY_R);
     pk.pack_map(2 + (not st.empty()?1:0) + (nodes.size()>0?1:0) + (nodes6.size()>0?1:0) + (not token.empty()?1:0));
@@ -1012,10 +1049,13 @@ NetworkEngine::sendNodesValues(const SockAddr& addr, Tid tid, const Blob& nodes,
 
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y); pk.pack(KEY_R);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     // send response
     send(addr, buffer.data(), buffer.size());
@@ -1087,7 +1127,7 @@ NetworkEngine::sendListen(const Sp<Node>& n,
     Tid tid (n->getNewTid());
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(5+(config.network?1:0));
+    pk.pack_map(5+(config.network?1:0)+(config.is_client?1:0));
 
     auto has_query = not query.where.empty() or not query.select.empty();
     pk.pack(KEY_A); pk.pack_map(5 + has_query);
@@ -1103,10 +1143,13 @@ NetworkEngine::sendListen(const Sp<Node>& n,
     pk.pack(KEY_Q); pk.pack(QUERY_LISTEN);
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y); pk.pack(KEY_Q);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     auto req = std::make_shared<Request>(MessageType::Listen, tid, n,
         Blob(buffer.data(), buffer.data() + buffer.size()),
@@ -1128,7 +1171,7 @@ void
 NetworkEngine::sendListenConfirmation(const SockAddr& addr, Tid tid) {
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(4+(config.network?1:0));
+    pk.pack_map(4+(config.network?1:0)+(config.is_client?1:0));
 
     pk.pack(KEY_R); pk.pack_map(2);
       pk.pack(KEY_REQ_ID); pk.pack(myid);
@@ -1136,10 +1179,13 @@ NetworkEngine::sendListenConfirmation(const SockAddr& addr, Tid tid) {
 
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y); pk.pack(KEY_R);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     send(addr, buffer.data(), buffer.size());
 }
@@ -1156,7 +1202,7 @@ NetworkEngine::sendAnnounceValue(const Sp<Node>& n,
     Tid tid (n->getNewTid());
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(5+(config.network?1:0));
+    pk.pack_map(5+(config.network?1:0)+(config.is_client?1:0));
 
     bool add_created = created < scheduler.time();
     pk.pack(KEY_A); pk.pack_map(add_created ? 5 : 4);
@@ -1172,10 +1218,13 @@ NetworkEngine::sendAnnounceValue(const Sp<Node>& n,
     pk.pack(KEY_Q);   pk.pack(QUERY_PUT);
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y);   pk.pack(KEY_Q);
-    pk.pack(KEY_UA);  pk.pack(my_v);
+    pk.pack(KEY_UA);  pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     auto req = std::make_shared<Request>(MessageType::AnnounceValue, tid, n,
         Blob(buffer.data(), buffer.data() + buffer.size()),
@@ -1242,7 +1291,7 @@ NetworkEngine::sendUpdateValues(const Sp<Node>& n,
 
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(5+(config.network?1:0));
+    pk.pack_map(5+(config.network?1:0)+(config.is_client?1:0));
 
     pk.pack(KEY_A); pk.pack_map((created < scheduler.time() ? 7 : 6));
       pk.pack(KEY_REQ_ID);     pk.pack(myid);
@@ -1259,10 +1308,13 @@ NetworkEngine::sendUpdateValues(const Sp<Node>& n,
     pk.pack(KEY_Q);   pk.pack(QUERY_UPDATE);
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y);   pk.pack(KEY_Q);
-    pk.pack(KEY_UA);  pk.pack(my_v);
+    pk.pack(KEY_UA);  pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     auto req = std::make_shared<Request>(MessageType::UpdateValue, tid, n,
         Blob(buffer.data(), buffer.data() + buffer.size()),
@@ -1287,7 +1339,7 @@ NetworkEngine::sendRefreshValue(const Sp<Node>& n,
     Tid tid (n->getNewTid());
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(5+(config.network?1:0));
+    pk.pack_map(5+(config.network?1:0)+(config.is_client?1:0));
 
     pk.pack(KEY_A); pk.pack_map(4);
       pk.pack(KEY_REQ_ID);       pk.pack(myid);
@@ -1298,10 +1350,13 @@ NetworkEngine::sendRefreshValue(const Sp<Node>& n,
     pk.pack(KEY_Q); pk.pack(QUERY_REFRESH);
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y); pk.pack(KEY_Q);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     auto req = std::make_shared<Request>(MessageType::Refresh, tid, n,
         Blob(buffer.data(), buffer.data() + buffer.size()),
@@ -1333,7 +1388,7 @@ void
 NetworkEngine::sendValueAnnounced(const SockAddr& addr, Tid tid, Value::Id vid) {
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(4+(config.network?1:0));
+    pk.pack_map(4+(config.network?1:0)+(config.is_client?1:0));
 
     pk.pack(KEY_R); pk.pack_map(3);
       pk.pack(KEY_REQ_ID);  pk.pack(myid);
@@ -1342,10 +1397,13 @@ NetworkEngine::sendValueAnnounced(const SockAddr& addr, Tid tid, Value::Id vid)
 
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y); pk.pack(KEY_R);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     send(addr, buffer.data(), buffer.size());
 }
@@ -1359,7 +1417,7 @@ NetworkEngine::sendError(const SockAddr& addr,
 {
     msgpack::sbuffer buffer;
     msgpack::packer<msgpack::sbuffer> pk(&buffer);
-    pk.pack_map(4 + (include_id?1:0) + (config.network?1:0));
+    pk.pack_map(4 + (include_id?1:0) + (config.network?1:0)+(config.is_client?1:0));
 
     pk.pack(KEY_E); pk.pack_array(2);
       pk.pack(code);
@@ -1372,10 +1430,13 @@ NetworkEngine::sendError(const SockAddr& addr,
 
     pk.pack(KEY_TID); pk.pack(tid);
     pk.pack(KEY_Y); pk.pack(KEY_E);
-    pk.pack(KEY_UA); pk.pack(my_v);
+    pk.pack(KEY_UA); pk.pack(OPENDHT_UA);
     if (config.network) {
         pk.pack(KEY_NETID); pk.pack(config.network);
     }
+    if (config.is_client) {
+        pk.pack(KEY_ISCLIENT); pk.pack(config.is_client);
+    }
 
     send(addr, buffer.data(), buffer.size());
 }
