@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Savoir-faire Linux Inc.
+ * Copyright (C) 2021-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,13 +21,12 @@
 #include "previewengine.h"
 #include "qmlregister.h"
 #include "systemtray.h"
-#include "videoprovider.h"
-#include "api/profile.h"
-#include "api/account.h"
-#include "api/conversationmodel.h"
-#include "api/contactmodel.h"
 
-#include <atomic>
+#include <api/profile.h>
+#include <api/account.h>
+#include <api/conversationmodel.h>
+#include <api/contactmodel.h>
+#include <api/contact.h>
 
 #include <QFontDatabase>
 #include <QQmlContext>
@@ -36,7 +35,7 @@
 #include <QtQuickTest/quicktest.h>
 #include <QSignalSpy>
 
-#ifdef WITH_WEBENGINE
+#if WITH_WEBENGINE
 #include <QtWebEngineCore>
 #include <QtWebEngineQuick>
 #endif
@@ -45,7 +44,19 @@
 #include <windows.h>
 #endif
 
+#ifdef Q_OS_WIN
+#define DATA_DIR   "JAMI_DATA_HOME"
+#define CONFIG_DIR "JAMI_CONFIG_HOME"
+#define CACHE_DIR  "JAMI_CACHE_HOME"
+#else
+#define DATA_DIR   "XDG_DATA_HOME"
+#define CONFIG_DIR "XDG_CONFIG_HOME"
+#define CACHE_DIR  "XDG_CACHE_HOME"
+#endif
+
+#include <atomic>
 #include <thread>
+
 using namespace std::literals::chrono_literals;
 
 class Setup : public QObject
@@ -74,6 +85,11 @@ public Q_SLOTS:
      */
     void applicationAvailable()
     {
+        QLoggingCategory::setFilterRules("\n"
+                                         "*.debug=false\n"
+                                         "libclient.debug=false\n"
+                                         "\n");
+
         connectivityMonitor_.reset(new ConnectivityMonitor(this));
         settingsManager_.reset(new AppSettingsManager(this));
         systemTray_.reset(new SystemTray(settingsManager_.get(), this));
@@ -81,23 +97,24 @@ public Q_SLOTS:
 
         QFontDatabase::addApplicationFont(":/images/FontAwesome.otf");
 
-        lrcInstance_.reset(
-            new LRCInstance(nullptr, nullptr, "", connectivityMonitor_.get(), true, muteDaemon_));
+        lrcInstance_.reset(new LRCInstance("", connectivityMonitor_.get(), true, muteDaemon_));
         lrcInstance_->subscribeToDebugReceived();
 
         auto downloadPath = settingsManager_->getValue(Settings::Key::DownloadPath);
         lrcInstance_->accountModel().downloadDirectory = downloadPath.toString() + "/";
 
-        // Create 2 Account
-        QSignalSpy accountStatusChangedSpy(&lrcInstance_->accountModel(),
-                                        &AccountModel::accountStatusChanged);
-
+        // Create 2 Accounts
         QSignalSpy accountAddedSpy(&lrcInstance_->accountModel(), &AccountModel::accountAdded);
-        aliceId = lrcInstance_->accountModel().createNewAccount(profile::Type::JAMI, "Alice");
+
+        MapStringString aliceDetails;
+        aliceDetails["alias"] = "Alice";
+        aliceId = lrcInstance_->accountModel().createNewAccount(profile::Type::JAMI, aliceDetails);
         accountAddedSpy.wait(15000);
         QCOMPARE(accountAddedSpy.count(), 1);
 
-        bobId = lrcInstance_->accountModel().createNewAccount(profile::Type::JAMI, "Bob");
+        MapStringString bobDetails;
+        bobDetails["alias"] = "Bob";
+        bobId = lrcInstance_->accountModel().createNewAccount(profile::Type::JAMI, bobDetails);
         accountAddedSpy.wait(15000);
         QCOMPARE(accountAddedSpy.count(), 2);
 
@@ -136,16 +153,9 @@ public Q_SLOTS:
                              systemTray_.get(),
                              settingsManager_.get(),
                              connectivityMonitor_.get(),
+                             previewEngine_.get(),
                              &screenInfo_,
                              this);
-
-        auto videoProvider = new VideoProvider(lrcInstance_->avModel(), this);
-        engine->rootContext()->setContextProperty("videoProvider", videoProvider);
-#ifdef WITH_WEBENGINE
-        engine->rootContext()->setContextProperty("WITH_WEBENGINE", QVariant(true));
-#else
-        engine->rootContext()->setContextProperty("WITH_WEBENGINE", QVariant(false));
-#endif
     }
 
     /*
@@ -182,9 +192,9 @@ main(int argc, char** argv)
     QDir(jamiConfigDir).removeRecursively();
     QDir(jamiCacheDir).removeRecursively();
 
-    bool envSet = qputenv("JAMI_DATA_HOME", jamiDataDir.toLocal8Bit());
-    envSet &= qputenv("JAMI_CONFIG_HOME", jamiConfigDir.toLocal8Bit());
-    envSet &= qputenv("JAMI_CACHE_HOME", jamiCacheDir.toLocal8Bit());
+    bool envSet = qputenv(DATA_DIR, jamiDataDir.toLocal8Bit());
+    envSet &= qputenv(CONFIG_DIR, jamiConfigDir.toLocal8Bit());
+    envSet &= qputenv(CACHE_DIR, jamiCacheDir.toLocal8Bit());
     if (!envSet)
         return 1;
 
@@ -196,7 +206,7 @@ main(int argc, char** argv)
     // Allow the user to enable fatal warnings for certain tests.
     Utils::remove_argument(argv, argc, "--failonwarn", [&]() { qputenv("QT_FATAL_WARNINGS", "1"); });
 
-#ifdef WITH_WEBENGINE
+#if WITH_WEBENGINE
     QtWebEngineQuick::initialize();
 #endif
     QTEST_SET_MAIN_SOURCE_PATH
